Function to adjust the width and height of a basic graph depending
on the number of scenarios and labels.
Usage
adjust_wh(data, var_w, var_h)
Arguments
- data
a dataset used to create a basic graph.
- var_w
variable on which the width of the basic graph depends.
- var_h
variable on which the height of the basic graph depends.
Value
a list containing the width and the height of the basic graph to be created.