Function to adjust the width and height of a intersectional graph
depending on the number of scenarios and labels.
Usage
adjust_wh_is(data, var_w, var_h)
Arguments
- data
a dataset used to create an intersectional graph.
- var_w
variable on which the width of the intersectional graph depends.
- var_h
variable on which the height of the intersectional graph depends.
Value
a list containing the width and the height of the intersectional graph to be created.