Function that returns the set of variables for which the calculation of intersectional distributional impacts is available for EU countries.
Function that returns the set of variables for which the calculation of intersectional distributional impacts is available for EU countries.