Skip to contents

Function to save a csv file in which the set of variables must be introduced for the calculation of intersectional distributional impacts. Save the file, keep just the conbinations you are interested in and load in R.

Usage

ex_var_intersec()

Value

a csv file with the set of variables for which the calculation of intersectional distributional impacts is available