List containing long names for the socioeconomic and demographic categories to introduce them on the axes of the graphs
Source:R/data.R
graph_labels.RdList containing long names for the socioeconomic and demographic categories to introduce them on the axes of the graphs