List of available variables for EU countries and long names for the socioeconomic and demographic categories to introduce them on the axes of the graphs
Source:R/data.R
graph_labels_eu.RdList of available variables for EU countries and long names for the socioeconomic and demographic categories to introduce them on the axes of the graphs