List containing the socioeconomic and demographic categories for the calculation of intersectional distributional impacts
Source:R/data.R
is_categories.RdList containing the socioeconomic and demographic categories for the calculation of intersectional distributional impacts