List containing the socioeconomic and demographic categories for the calculation of intersectional distributional impacts for EU countries
Source:R/data.R
is_categories_eu.RdList containing the socioeconomic and demographic categories for the calculation of intersectional distributional impacts for EU countries