Function to rename the codified values of the dataset to the meaningful values detailed in the mapping included in the package.
Function to rename the codified values of the dataset to the meaningful values detailed in the mapping included in the package.