Example csv file in which the change in prices must be introduced to apply a price shock to EU microdata
Source:R/data.R
shocks_eu.RdExample csv file in which the change in prices must be introduced to apply a price shock to EU microdata
R/data.R
shocks_eu.RdExample csv file in which the change in prices must be introduced to apply a price shock to EU microdata