Example csv file in which the change in prices must be introduced to apply multiple scenarios and price shocks to EU microdata
Source:R/data.R
shocks_eu_s.RdExample csv file in which the change in prices must be introduced to apply multiple scenarios and price shocks to EU microdata