Skip to contents

Function to update the expenditure data of the HBS

Usage

update_year(data, new_year)

Arguments

data

dataframe with the hbs data to update (The COICOP codes in the dataframe must be renamed beforehand using rename_coicop.)

new_year

year to which you want to update the microdata

Value

data file with the updated expenditure data