Function to save a csv file in which the change in prices must be introduced to apply a price shock for EU countries. Save the file, introduce the price shocks and load in R.
Function to save a csv file in which the change in prices must be introduced to apply a price shock for EU countries. Save the file, introduce the price shocks and load in R.