Function to save a csv file in which the set of variables must be introduced for the calculation of intersectional distributional impacts. Save the file, keep just the conbinations you are interested in and load in R.
Function to save a csv file in which the set of variables must be introduced for the calculation of intersectional distributional impacts. Save the file, keep just the conbinations you are interested in and load in R.